searchData={"items":[{"type":"module","title":"Sqlcommenter","doc":"# Sqlcommenter\n\nDisclaimer: Currently using comments disables prepared statements and may increase cpu load on\nyour database.\nElixir implementation of [sqlcommenter](https://google.github.io/sqlcommenter/) escaping.\nAttach SQL comments to correlate user code in ORMs and SQL drivers with SQL statements.","ref":"Sqlcommenter.html"},{"type":"module","title":"Usage - Sqlcommenter","doc":"Add these callbacks to your Repo module, adjust to your needs.\n  The stacktrace option is only required when you plan to include use the extract_repo_caller\n  function.  This function also accepts the __MODULE__ as the second argument to exclude it\n  from the stacktrace.\n\n The sqlcommenter option is used for adding static data to the comment like the running app,\n team, owner etc.  Any dynamic data can be added in the prepare_query function. Besides the\n caller it can also add the trace and span.\n\nThe generated comment needs to be added as comment option - this will be passed to the adapter.\n\n```elixir\ndef default_options(_operation) do\n  [stacktrace: true, prepare: :unnamed, sqlcommenter: [team: \"sqlcomm\", app: \"sqlcomm\"]]\nend\n\ndef prepare_query(_operation, query, opts) do\n  sqlcommennter_defaults = Keyword.get(opts, :sqlcommenter)\n  caller = Sqlcommenter.extract_repo_caller(opts, __MODULE__)\n  comment = Sqlcommenter.to_str([caller: caller] ++ sqlcommenter_defaults)\n\n  {query, [comment: comment] ++ opts}\nend\n```\n\nNow your postgres logs should look will return a log line like this:\n\n```\n2024-10-27 21:43:04.331 GMT,\"postgres\",\"sqlcomm_test\",416336,\"127.0.0.1:53348\",671eb3e8.65a50,6, \"SELECT\",2024-10-27 21:43:04 GMT,15/54,61620,LOG,00000,\"execute  : SELECT u0.\"\"id\"\",\nu0.\"\"active\"\", u0.\"\"name\"\", u0.\"\"inserted_at\"\", u0.\"\"updated_at\"\" FROM \"\"users\"\" AS\nu0/*app='sqlcomm',caller='Elixir.SqlcommTest.test%20insert%20user%2F1',team='sqlcomm'*/\"\n,,,,,,,,,\"\",\"client backend\",,0\n```\n\nAlternatively, when you're concerned about performance and your options are mostly static\nyou can also omit the Sqlcommenter logic and write your own custom function.\nJust remember that according the sqlcommenter specs the keys must be sorted,\nand the values properly escaped check [specification](https://google.github.io/sqlcommenter/spec/) and sqlcommenter source code.\n\n```elixir\ndefmodule SqlEEx do\n   require EEx\n\n  EEx.function_from_string(\n    :def,\n    :to_comment,\n    \"app:'sqlcomm',caller:'<%= caller %>'team:'sqlcomm'\",\n    [:caller]\n  )\nend\n```\n\nAnd then use it in your repo:\n```elixir\ndef prepare_query(_operation, query, opts) do\n  caller = Sqlcommenter.extract_repo_caller(opts, __MODULE__)\n  SqlEEx.to_comment(caller: caller)\n  {query, [comment: comment] ++ opts}\nend\n```\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). Once published, the docs can\nbe found at  .","ref":"Sqlcommenter.html#module-usage"},{"type":"function","title":"Sqlcommenter.append_to_io_query/2","doc":"Appends serialized data to query\n\niex> query = [\"SELECT\", [~s{p0.\"id\"}, \", \", ~s{p0.\"first_name\"}], \" FROM \", ~s{\"person\".\"person\"}, \" AS \", \"p0\"]\niex> Sqlcommenter.append_to_io_query(query, %{controller: :person, function: :index})\n[\n  [\"SELECT\", [~s{p0.\"id\"}, \", \", ~s{p0.\"first_name\"}], \" FROM \", ~s{\"person\".\"person\"}, \" AS \", \"p0\"],\n  \" /*\",\n  [\n    [\"controller\", \"='\", \"person\", \"'\"],\n    \",\",\n    [\"function\", \"='\", \"index\", \"'\"]\n ],\n\"*/\"]","ref":"Sqlcommenter.html#append_to_io_query/2"},{"type":"function","title":"Sqlcommenter.append_to_query/2","doc":"Appends serialized data to query\n\niex> query = ~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0}\niex> Sqlcommenter.append_to_query(query, %{controller: :person, function: :index})\n~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0 } <>\n\"/*controller='person',function='index'*/\"","ref":"Sqlcommenter.html#append_to_query/2"},{"type":"function","title":"Sqlcommenter.deserialize/1","doc":"extracts serialized data from query","ref":"Sqlcommenter.html#deserialize/1"},{"type":"function","title":"Example - Sqlcommenter.deserialize/1","doc":"iex> query = ~s{SELECT p0.\"id\", p0.\"first_name\" FROM \"person\".\"person\" AS p0 /*request_id='fa2af7b2-d8e1-4e8f-8820-3fd648b73187'*/}\niex> Sqlcommenter.deserialize(query)\n%{\"request_id\" => \"fa2af7b2-d8e1-4e8f-8820-3fd648b73187\"}","ref":"Sqlcommenter.html#deserialize/1-example"},{"type":"function","title":"Sqlcommenter.extract_repo_caller/2","doc":"","ref":"Sqlcommenter.html#extract_repo_caller/2"},{"type":"function","title":"Sqlcommenter.sorted_to_iodata/1","doc":"The same as to_iodata but it assumes the keys are sorted already.","ref":"Sqlcommenter.html#sorted_to_iodata/1"},{"type":"function","title":"Sqlcommenter.to_iodata/1","doc":"Encodes enumerable to iodata\niex> Sqlcommenter.to_iodata(controller: :person, function: :index)\n[\n    [\"controller\", \"='\", \"person\", \"'\"],\n    \",\",\n    [\"function\", \"='\", \"index\", \"'\"]\n]","ref":"Sqlcommenter.html#to_iodata/1"},{"type":"function","title":"Sqlcommenter.to_str/1","doc":"Encodes enumerable to string\niex> Sqlcommenter.to_str(controller: :person, function: :index)\n\"controller='person',function='index'\"","ref":"Sqlcommenter.html#to_str/1"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}